## Product details

The IMIPAW 101oz Smart Automatic Cat Feeder is a versatile and convenient solution for pet owners. With its WiFi connectivity and mobile app, you can remotely monitor your pet's feeding habits, adjust meal plans, and even interact with them through the built-in HD camera and two-way audio. The precision structure ensures consistent portion sizes, while the sealed space safety lock cover keeps the food fresh and prevents any messes. Customizable feeding schedules, video recording, and a satisfaction guarantee make this smart feeder a reliable choice for your furry friend's health and well-being.
‌SMART REMOTE APP CONTROL: The automatic cat feeder supports 2.4GHz WiFi, easily connect to your home network using the "PetTech" APP. Use the sharing function to plan a diet for your pet with your family
GUARDING PET'S HEALTH: Customized meal plan to help develop good eating habits, customized healthy diet for them through the food dispenser, 1-10 meals per day, up to 20 servings per meal (1 tbsp/1 portion) depending on your pet's needs, and allow them to have a healthier lifestyle
Heartwarming Meal Reminder: The feeder can record personalized voice for your pet, with a recording time of up to 10 seconds. The voice will automatically play at food time to remind your pet to eat, so that your pet can also feel your company while eating
Dual power supply configuration: The timed cat feeder has two power supply systems, supporting 5V/1A power adapter and 3 alkaline D batteries (not included). Enjoy an uninterrupted eating experience during power outages, ensuring that your beloved Pets receive a continuous supply of food when the power goes out at home
Satisfaction: If you have any problems while using this timed cat feeder, please contact us for specific instructions. Hope our cat food feeder can help all pet owners reduce the burden of taking care of their pets and get the most pleasant purchasing experience from us
info:
We aim to show you accurate product information. Manufacturers, suppliers and others provide what you see here, and we have not verified it.  See our disclaimer
## Specifications

Automatic pet feeder type
Automatic Feeder
Capacity
3 L
Volume capacity
3 L
Water capacity
3 L
More details
Warranty

## Warranty information
1year
